# main.py
import machine
import usocket as socket
import time
from esc import Esc
# local
from credentials import *
import wifi

# import web

## Pins
## M1: left, M2: right
# PIN_M1_ENA = 5 # D1
# PIN_M1_IN1 = 4 # D2
# PIN_M1_IN2 = 0 # D3
# PIN_M2_IN1 = 12 # D6
# PIN_M2_IN2 = 13 # D7
# PIN_M2_ENA = 15 # D8
## M1: right, M2: left
PIN_M1_IN1 = 12 # D6
PIN_M1_IN2 = 13 # D7
PIN_M1_ENA = 15 # D8
PIN_M2_ENA = 5 # D1
PIN_M2_IN1 = 4 # D2
PIN_M2_IN2 = 0 # D3
## Parameters
T_NEUTRAL=0.5
T_STATUS=2

## Variables
esc = None

def main():
    print("main")
    global esc
    # wifiSTA = wifi.WifiSTA(SSID, PASS)
    wifiAP = wifi.WifiAP(SSID, PASS)
    wifiAP.connect()
    esc = Esc(PIN_M1_ENA, PIN_M1_IN1, PIN_M1_IN2,
              PIN_M2_ENA, PIN_M2_IN1, PIN_M2_IN2)
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    s.setsockopt(socket.SOL_SOCKET,socket.SO_REUSEADDR, 1)
    s.settimeout(0.1)
    s.bind(("", 80))

    ts_cmd = 0
    ts_status = 0
    while True:
        # wifiSTA.check()
        request = ""
        try:
            request, addr = s.recvfrom(256)
        except OSError as ex:
            pass
        except Exception as ex:
            print("Exception Type:{}, args: {}".format(type(ex).__name__, ex.args))

        if len(request) > 0:
            print('len > 0')
            ts_cmd = time.time()
            req = request.decode()
            print("data: {}, from: {}".format(req, addr))

            ## buttons
            if "accel" in req:
                esc.accel()
                print(esc.get_status())
            elif "left" in req:
                esc.left()
                print(esc.get_status())
            elif "decel" in req:
                esc.decel()
                print(esc.get_status())
            elif "right" in req:
                esc.right()
                print(esc.get_status())
            elif "stop" in req:
                esc.stop()
                print(esc.get_status())
            elif "rotate" in req:
                esc.rotate()
            else:
                print("unknown: {}".format(req))


        if time.time() > (ts_cmd + T_NEUTRAL):
            ts_cmd = time.time()
            # print(" -: neutral")
            esc.neutral()
            # print(esc.get_status())

        if time.time() > (ts_status + T_STATUS):
            ts_status = time.time()
            print(esc.get_status())


if __name__ == "__main__":
    main()
