import machine
import time


class Motor:
    PWM_MAX = 1023
    DIR_FWD = 1
    DIR_REV = 0

    def __init__(self, name, ena, p1, p2):
        self.name = name
        self.pin1 = machine.Pin(p1, machine.Pin.OUT)
        self.pin2 = machine.Pin(p2, machine.Pin.OUT)
        self.pwm = machine.PWM(machine.Pin(ena, machine.Pin.OUT))
        self.pwm.freq(1000)
        # state
        self.dir = -1
        self.speed = -1
        time.sleep(1)
        # initialize motors
        self.set_speed(0)

    def get_status(self):
        s = "[{}:status] pins {},{} duty {}".format(
            self.name, self.pin1.value(), self.pin2.value(), self.pwm.duty())
        return s

    def set_dir(self, dir):
        if self.dir == dir:
            return
        self.dir = dir
        v1 = 1 if self.dir == self.DIR_FWD else 0
        v2 = 0 if self.dir == self.DIR_FWD else 1
        self.pin1.value(v1)
        self.pin2.value(v2)

    def set_speed(self, speed):
        # print("{}:set_speed] {} -100:100".format(self.name, speed))
        if (speed < 0):
            self.set_dir(self.DIR_REV)
        else:
            self.set_dir(self.DIR_FWD)
        self.speed = speed
        s = int(self.PWM_MAX * abs(speed)/100)
        self.pwm.duty(s)

    def inc(self, delta):
        speed = min(self.speed + delta, 100)
        self.set_speed(speed)

    def dec(self, delta):
        speed = max(self.speed - delta, -100)
        self.set_speed(speed)
